@@ -39,7 +39,7 @@ def find_nearby_projects(project_name, dist=10, print_data=True, include_retired
             df = df.query("Retired != True")
 
     # Rename 'Tilt/GCR' column to a valid python identifier
-    df.rename(columns={'Tilt/GCR':'Tilt_GCR'}, inplace=True)
+    df = df.copy().rename(columns={'Tilt/GCR':'Tilt_GCR'})
     
     # Get a dictionary of site information, then the required parameters for the query
     site_info = df.loc[[project_name]].to_dict('index')[project_name]
@@ -130,7 +130,7 @@ def find_nearby_similar_projects(project_name, dist=10, print_data=True, include
         DataFrame: Contains information about all sites within a certain distance\
         of the reference site that share similar racking properties.
     """
-    nearby_sites = find_nearby_projects(project_name, dist, include_retired, df)
+    nearby_sites = find_nearby_projects(project_name, print_data=print_data, dist=dist, include_retired=include_retired, df=df)
     nearby_similar_sites = find_similar_projects(project_name, df=nearby_sites)
     
     if print_data:
@@ -161,5 +161,5 @@ def haversine(lon1, lat1, lon2, lat2):
     a = np.sin(dlat/2.0)**2 + np.cos(lat1) * np.cos(lat2) * np.sin(dlon/2.0)**2
 
     c = 2 * np.arcsin(np.sqrt(a))
-    dist_miles = 3798 * c
+    dist_miles = 3959 * c
     return dist_miles
\ No newline at end of file
